==> ideaIC-141.3057.6-sources.jar: com/intellij/refactoring/extractclass/usageInfo/ReplaceStaticVariableIncrementDecrement.java <==
/*
 * Copyright 2000-2009 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.refactoring.extractclass.usageInfo;

import com.intellij.psi.PsiExpression;
import com.intellij.psi.PsiPostfixExpression;
import com.intellij.psi.PsiPrefixExpression;
import com.intellij.psi.util.PsiTreeUtil;
import com.intellij.refactoring.psi.MutationUtils;
import com.intellij.refactoring.util.FixableUsageInfo;
import com.intellij.util.IncorrectOperationException;

public class ReplaceStaticVariableIncrementDecrement extends FixableUsageInfo {
  private final PsiExpression reference;
  private final String originalClassName;

  public ReplaceStaticVariableIncrementDecrement(PsiExpression reference, String originalClassName) {
    super(reference);
    this.originalClassName = originalClassName;
    final PsiPrefixExpression prefixExpr = PsiTreeUtil.getParentOfType(reference, PsiPrefixExpression.class);
    if (prefixExpr != null) {
      this.reference = prefixExpr;
    }
    else {
      this.reference = PsiTreeUtil.getParentOfType(reference, PsiPostfixExpression.class);
    }
  }

  public void fixUsage() throws IncorrectOperationException {
    MutationUtils.replaceExpression(originalClassName + '.' + reference.getText(), reference);
  }
}

==> ideaIC-182.3208.16-sources.jar: com/intellij/refactoring/extractclass/usageInfo/ReplaceStaticVariableIncrementDecrement.java <==
/*
 * Copyright 2000-2009 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.refactoring.extractclass.usageInfo;

import com.intellij.psi.PsiExpression;
import com.intellij.psi.PsiUnaryExpression;
import com.intellij.psi.util.PsiTreeUtil;
import com.intellij.refactoring.psi.MutationUtils;
import com.intellij.refactoring.util.FixableUsageInfo;
import com.intellij.util.IncorrectOperationException;

public class ReplaceStaticVariableIncrementDecrement extends FixableUsageInfo {
  private final PsiUnaryExpression reference;
  private final String originalClassName;

  public ReplaceStaticVariableIncrementDecrement(PsiExpression reference, String originalClassName) {
    super(reference);
    this.originalClassName = originalClassName;
    this.reference = PsiTreeUtil.getParentOfType(reference, PsiUnaryExpression.class);
  }

  public void fixUsage() throws IncorrectOperationException {
    MutationUtils.replaceExpression(originalClassName + '.' + reference.getText(), reference);
  }
}
